@@ -57,7 +57,9 @@ class DefaultActorFailed(Exception):
     pass
 
 class GroupFailed(Exception):
-    pass
+    def __init__(self, msg, group_name):
+        Exception.__init__(self, msg)
+        self.group_name = group_name
 
 class WrongMessageTypeSpecified(Exception):
     pass
@@ -230,7 +232,7 @@ class ActorManager(messaging.MessageManager):
         if self.is_main_process:
             for group, (p, _id, switch) in self.groups.items():    
                 if not processing.is_alive(p):
-                    raise GroupFailed('Group "%s" failed' % group)
+                    raise GroupFailed('Group "%s" failed' % group, group)
 
         # always poll at least one ipc message here
         has_more = True
@@ -247,7 +249,7 @@ class ActorManager(messaging.MessageManager):
                 if cut_off_time and util.get_time() > cut_off_time:
                     break
 
-        self.log(logging.DEBUG, 'process "%s" queue length: %s' % (processing.get_pid(processing.current_process()), self.queue_length))
+#        self.log(logging.DEBUG, 'process "%s" queue length: %s' % (processing.get_pid(processing.current_process()), self.queue_length))
         
         # process all messages first
         new_max_time = None
@@ -308,6 +310,20 @@ class ActorManager(messaging.MessageManager):
             raise PacketTypeError('Packet_type must be specified by class "%s"' % type(msg))
         self.transport.send(msg.to_string(), address=address)
         return self
+    def send_message_with_transport(self, msg, transport, address=None):
+        '''
+        send a message to a network with a externally instanced transport.  Mainly used for connecting to multiple servers.  
+        The specified transport can only be used here to send.
+        
+        :Parameters:
+            - `msg`: the message to send
+            - `trasnport`: the transport instance to send the message with
+            - `address`: the address to send the message to
+        '''
+        if not type(msg).packet_type:
+            raise PacketTypeError('Packet_type must be specified by class "%s"' % type(msg))
+        transport.send(msg.to_string(), address=address)
+        return self
     def queue_message_to_group(self, group, msg):
         '''message is serialized and sent to the group (process) specified'''
         if not self.groups.has_key(group):
@@ -322,7 +338,6 @@ class ActorManager(messaging.MessageManager):
         return self
     def packet_handler(self, packet, address):
         packetid = ord(packet[0])
-        processing.get_logger().debug('Received packet of type "%s"' % type)
         if packetid < 100:
             processing.get_logger().warning('internal packet unhandled: "%s"' % self.transport.packet_type_info(packetid))
             return self
