@@ -13,6 +13,9 @@ except ImportError:
 else:
     RAKNET_AVAILABLE = True
     
+class NotConnectedException(Exception):
+    pass
+    
 logger = processing.get_logger()
 
 class Transport(object):
@@ -142,7 +145,7 @@ class SelectTCPTransport(Transport):
         if sock in self.buffer:
             del self.buffer[sock]
     def poll_server(self, packet_handler):
-        logger.debug('server pid %s polling...' % os.getpid())
+#        logger.debug('server pid %s polling...' % os.getpid())
         processed = False
         try:
             inputready, outputready, exceptready = select.select([self.socket] + self.peers, [], [], 0)
@@ -174,10 +177,11 @@ class SelectTCPTransport(Transport):
                         self.process_received_data(sock, addr, data, packet_handler)
                     else:
                         # client closed connection, they are done sending the message
+                        logger.debug('Client %s disconnected' % str(addr))
                         sock.close()
                         self.remove_socket(sock)
                 except socket.error, e:
-                    logger.error('%s Error receiving data: %s' % ('Client' if self._is_connected else 'Server', e))
+                    logger.error('Server had error receiving data: %s' % e)
                     sock.close()
                     self.remove_socket(sock)
             processed = True
@@ -190,7 +194,7 @@ class SelectTCPTransport(Transport):
         else:
             return
     def poll_client(self, packet_handler):
-        logger.debug('client pid %s polling...' % os.getpid())
+#        logger.debug('client pid %s polling...' % os.getpid())
         processed = False
         try:
             inputready, outputready, exceptready = select.select([self.socket], [], [], 0)
@@ -232,12 +236,15 @@ class SelectTCPTransport(Transport):
         self._is_connected = False
         self._is_server = False
     def send(self, data, address=None, broadcast=False):
-        logger.debug('%s pid %s sending...%s' % ('server' if self.is_server() else 'client', os.getpid(), time.time()))
+#        logger.debug('%s pid %s sending...%s' % ('server' if self.is_server() else 'client', os.getpid(), time.time()))
         data = struct.pack("!L",len(data)) + data
         sock = None
         if address:
             logger.debug('%s\'s addrs: %s' % ('server' if self.is_server() else 'client', self.addrs))
-            sock = self.addrs[address]
+            try:
+                sock = self.addrs[address]
+            except KeyError, e:
+                raise NotConnectedException("Peer %s is not connected." % str(address))
         if sock:
             sock.sendall(data)
         elif self.is_client():
